.. arfs documentation master file, created by
   sphinx-quickstart on Mon Feb  7 15:05:24 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to arfs's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: User's guide

   Introduction
   Methods overview
   modules


.. toctree::
   :maxdepth: 4
   :glob:
   :caption: Tutorials

   notebooks/Classification.ipynb
   notebooks/Regression.ipynb
   notebooks/pre-filtering.ipynb
   notebooks/Categoricals.ipynb
   notebooks/Collinearity.ipynb
   notebooks/large_data_sampling.ipynb
   notebooks/Boruta_comparison.ipynb
   notebooks/BorutaShap_comparison.ipynb
   


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
